@@ -1,17 +1,19 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
-use crate::deserialize::utf8::read_input_to_buf;
 use crate::deserialize::DeserializeError;
+use crate::deserialize::utf8::read_input_to_buf;
 use crate::typeref::EMPTY_UNICODE;
 use core::ptr::NonNull;
 
-pub fn deserialize(
-    ptr: *mut pyo3_ffi::PyObject,
-) -> Result<NonNull<pyo3_ffi::PyObject>, DeserializeError<'static>> {
+pub(crate) fn deserialize(
+    ptr: *mut crate::ffi::PyObject,
+) -> Result<NonNull<crate::ffi::PyObject>, DeserializeError<'static>> {
     debug_assert!(ffi!(Py_REFCNT(ptr)) >= 1);
     let buffer = read_input_to_buf(ptr)?;
+    debug_assert!(!buffer.is_empty());
 
-    if unlikely!(buffer.len() == 2) {
+    if buffer.len() == 2 {
+        cold_path!();
         if buffer == b"[]" {
             return Ok(nonnull!(ffi!(PyList_New(0))));
         } else if buffer == b"{}" {
