@@ -1,18 +1,18 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
+use crate::ffi::{Py_buffer, Py_hash_t, Py_ssize_t, PyObject, PyVarObject};
 use core::ffi::c_int;
-use pyo3_ffi::{PyObject, PyVarObject, Py_buffer, Py_hash_t, Py_ssize_t};
 
 #[repr(C)]
-pub struct _PyManagedBufferObject {
-    pub ob_base: *mut pyo3_ffi::PyObject,
+pub(crate) struct _PyManagedBufferObject {
+    pub ob_base: *mut PyObject,
     pub flags: c_int,
     pub exports: Py_ssize_t,
     pub master: *mut Py_buffer,
 }
 
 #[repr(C)]
-pub struct PyMemoryViewObject {
+pub(crate) struct PyMemoryViewObject {
     pub ob_base: PyVarObject,
     pub mbuf: *mut _PyManagedBufferObject,
     pub hash: Py_hash_t,
@@ -25,6 +25,6 @@ pub struct PyMemoryViewObject {
 
 #[allow(non_snake_case)]
 #[inline(always)]
-pub unsafe fn PyMemoryView_GET_BUFFER(op: *mut PyObject) -> *const Py_buffer {
+pub(crate) unsafe fn PyMemoryView_GET_BUFFER(op: *mut PyObject) -> *const Py_buffer {
     unsafe { &(*op.cast::<PyMemoryViewObject>()).view }
 }
