@@ -1,9 +1,8 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
-#![cfg_attr(feature = "intrinsics", feature(core_intrinsics))]
 #![cfg_attr(feature = "optimize", feature(optimize_attribute))]
 #![cfg_attr(feature = "generic_simd", feature(portable_simd))]
-#![allow(internal_features)] // core_intrinsics
+#![cfg_attr(feature = "cold_path", feature(cold_path))]
 #![allow(non_camel_case_types)]
 #![allow(stable_features)] // MSRV
 #![allow(static_mut_refs)]
@@ -26,6 +25,7 @@
 #![allow(clippy::host_endian_bytes)]
 #![allow(clippy::if_not_else)]
 #![allow(clippy::implicit_return)]
+#![allow(clippy::incompatible_msrv)] // MSRV 1.89
 #![allow(clippy::inline_always)]
 #![allow(clippy::let_underscore_untyped)]
 #![allow(clippy::missing_assert_message)]
@@ -81,48 +81,48 @@ mod serialize;
 mod str;
 mod typeref;
 
-use core::ffi::{c_char, c_int, c_void};
-use pyo3_ffi::{
-    PyCFunction_NewEx, PyErr_SetObject, PyLong_AsLong, PyLong_FromLongLong, PyMethodDef,
-    PyMethodDefPointer, PyModuleDef, PyModuleDef_HEAD_INIT, PyModuleDef_Slot, PyObject,
-    PyTuple_New, PyUnicode_FromStringAndSize, PyUnicode_InternFromString, PyVectorcall_NARGS,
-    Py_DECREF, Py_SIZE, Py_ssize_t, METH_KEYWORDS, METH_O,
+use crate::ffi::{
+    METH_KEYWORDS, METH_O, Py_DECREF, Py_SIZE, Py_ssize_t, PyCFunction_NewEx, PyErr_SetObject,
+    PyLong_AsLong, PyLong_FromLongLong, PyMethodDef, PyMethodDefPointer, PyModuleDef,
+    PyModuleDef_HEAD_INIT, PyModuleDef_Slot, PyObject, PyTuple_New, PyUnicode_FromStringAndSize,
+    PyUnicode_InternFromString, PyVectorcall_NARGS,
 };
+use core::ffi::{c_char, c_int, c_void};
 
 use crate::util::{isize_to_usize, usize_to_isize};
 
 #[allow(unused_imports)]
-use core::ptr::{null, null_mut, NonNull};
+use core::ptr::{NonNull, null, null_mut};
 
 #[cfg(Py_3_13)]
 macro_rules! add {
     ($mptr:expr, $name:expr, $obj:expr) => {
-        pyo3_ffi::PyModule_Add($mptr, $name.as_ptr(), $obj);
+        crate::ffi::PyModule_Add($mptr, $name.as_ptr(), $obj);
     };
 }
 
 #[cfg(all(Py_3_10, not(Py_3_13)))]
 macro_rules! add {
     ($mptr:expr, $name:expr, $obj:expr) => {
-        pyo3_ffi::PyModule_AddObjectRef($mptr, $name.as_ptr(), $obj);
+        crate::ffi::PyModule_AddObjectRef($mptr, $name.as_ptr(), $obj);
     };
 }
 
 #[cfg(not(Py_3_10))]
 macro_rules! add {
     ($mptr:expr, $name:expr, $obj:expr) => {
-        pyo3_ffi::PyModule_AddObject($mptr, $name.as_ptr(), $obj);
+        crate::ffi::PyModule_AddObject($mptr, $name.as_ptr(), $obj);
     };
 }
 
 macro_rules! opt {
     ($mptr:expr, $name:expr, $opt:expr) => {
         #[cfg(all(not(target_os = "windows"), target_pointer_width = "64"))]
-        pyo3_ffi::PyModule_AddIntConstant($mptr, $name.as_ptr(), i64::from($opt));
+        crate::ffi::PyModule_AddIntConstant($mptr, $name.as_ptr(), i64::from($opt));
         #[cfg(all(not(target_os = "windows"), target_pointer_width = "32"))]
-        pyo3_ffi::PyModule_AddIntConstant($mptr, $name.as_ptr(), $opt as i32);
+        crate::ffi::PyModule_AddIntConstant($mptr, $name.as_ptr(), $opt as i32);
         #[cfg(target_os = "windows")]
-        pyo3_ffi::PyModule_AddIntConstant($mptr, $name.as_ptr(), $opt as i32);
+        crate::ffi::PyModule_AddIntConstant($mptr, $name.as_ptr(), $opt as i32);
     };
 }
 
@@ -155,7 +155,7 @@ pub(crate) unsafe extern "C" fn orjson_init_exec(mptr: *mut PyObject) -> c_int {
                     #[cfg(not(Py_3_10))]
                     _PyCFunctionFastWithKeywords: dumps,
                 },
-                ml_flags: pyo3_ffi::METH_FASTCALL | METH_KEYWORDS,
+                ml_flags: crate::ffi::METH_FASTCALL | METH_KEYWORDS,
                 ml_doc: dumps_doc.as_ptr(),
             };
 
@@ -227,19 +227,19 @@ pub(crate) unsafe extern "C" fn PyInit_orjson() -> *mut PyModuleDef {
     unsafe {
         let mod_slots: Box<[PyModuleDef_Slot; PYMODULEDEF_LEN]> = Box::new([
             PyModuleDef_Slot {
-                slot: pyo3_ffi::Py_mod_exec,
+                slot: crate::ffi::Py_mod_exec,
                 #[allow(clippy::fn_to_numeric_cast_any, clippy::as_conversions)]
                 value: orjson_init_exec as *mut c_void,
             },
             #[cfg(Py_3_12)]
             PyModuleDef_Slot {
-                slot: pyo3_ffi::Py_mod_multiple_interpreters,
-                value: pyo3_ffi::Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED,
+                slot: crate::ffi::Py_mod_multiple_interpreters,
+                value: crate::ffi::Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED,
             },
             #[cfg(Py_3_13)]
             PyModuleDef_Slot {
-                slot: pyo3_ffi::Py_mod_gil,
-                value: pyo3_ffi::Py_MOD_GIL_USED,
+                slot: crate::ffi::Py_mod_gil,
+                value: crate::ffi::Py_MOD_GIL_USED,
             },
             PyModuleDef_Slot {
                 slot: 0,
@@ -314,7 +314,7 @@ fn raise_dumps_exception_fixed(msg: &str) -> *mut PyObject {
 #[cfg(Py_3_12)]
 fn raise_dumps_exception_dynamic(err: &str) -> *mut PyObject {
     unsafe {
-        let cause_exc: *mut PyObject = pyo3_ffi::PyErr_GetRaisedException();
+        let cause_exc: *mut PyObject = crate::ffi::PyErr_GetRaisedException();
 
         let err_msg =
             PyUnicode_FromStringAndSize(err.as_ptr().cast::<c_char>(), usize_to_isize(err.len()));
@@ -323,9 +323,9 @@ fn raise_dumps_exception_dynamic(err: &str) -> *mut PyObject {
         Py_DECREF(err_msg);
 
         if !cause_exc.is_null() {
-            let exc: *mut PyObject = pyo3_ffi::PyErr_GetRaisedException();
-            pyo3_ffi::PyException_SetCause(exc, cause_exc);
-            pyo3_ffi::PyErr_SetRaisedException(exc);
+            let exc: *mut PyObject = crate::ffi::PyErr_GetRaisedException();
+            crate::ffi::PyException_SetCause(exc, cause_exc);
+            crate::ffi::PyErr_SetRaisedException(exc);
         }
     }
     null_mut()
@@ -340,7 +340,7 @@ fn raise_dumps_exception_dynamic(err: &str) -> *mut PyObject {
         let mut cause_tp: *mut PyObject = null_mut();
         let mut cause_val: *mut PyObject = null_mut();
         let mut cause_traceback: *mut PyObject = null_mut();
-        pyo3_ffi::PyErr_Fetch(&mut cause_tp, &mut cause_val, &mut cause_traceback);
+        crate::ffi::PyErr_Fetch(&mut cause_tp, &mut cause_val, &mut cause_traceback);
 
         let err_msg =
             PyUnicode_FromStringAndSize(err.as_ptr().cast::<c_char>(), usize_to_isize(err.len()));
@@ -350,19 +350,23 @@ fn raise_dumps_exception_dynamic(err: &str) -> *mut PyObject {
         let mut tp: *mut PyObject = null_mut();
         let mut val: *mut PyObject = null_mut();
         let mut traceback: *mut PyObject = null_mut();
-        pyo3_ffi::PyErr_Fetch(&mut tp, &mut val, &mut traceback);
-        pyo3_ffi::PyErr_NormalizeException(&mut tp, &mut val, &mut traceback);
+        crate::ffi::PyErr_Fetch(&mut tp, &mut val, &mut traceback);
+        crate::ffi::PyErr_NormalizeException(&mut tp, &mut val, &mut traceback);
 
         if !cause_tp.is_null() {
-            pyo3_ffi::PyErr_NormalizeException(&mut cause_tp, &mut cause_val, &mut cause_traceback);
-            pyo3_ffi::PyException_SetCause(val, cause_val);
+            crate::ffi::PyErr_NormalizeException(
+                &mut cause_tp,
+                &mut cause_val,
+                &mut cause_traceback,
+            );
+            crate::ffi::PyException_SetCause(val, cause_val);
             Py_DECREF(cause_tp);
         }
         if !cause_traceback.is_null() {
             Py_DECREF(cause_traceback);
         }
 
-        pyo3_ffi::PyErr_Restore(tp, val, traceback);
+        crate::ffi::PyErr_Restore(tp, val, traceback);
     }
     null_mut()
 }
@@ -387,7 +391,8 @@ pub(crate) unsafe extern "C" fn dumps(
         let mut optsptr: Option<NonNull<PyObject>> = None;
 
         let num_args = PyVectorcall_NARGS(isize_to_usize(nargs));
-        if unlikely!(num_args == 0) {
+        if num_args == 0 {
+            cold_path!();
             return raise_dumps_exception_fixed(
                 "dumps() missing 1 required positional argument: 'obj'",
             );
@@ -398,18 +403,21 @@ pub(crate) unsafe extern "C" fn dumps(
         if num_args & 3 == 3 {
             optsptr = Some(NonNull::new_unchecked(*args.offset(2)));
         }
-        if unlikely!(!kwnames.is_null()) {
+        if !kwnames.is_null() {
+            cold_path!();
             for i in 0..=Py_SIZE(kwnames).saturating_sub(1) {
                 let arg = crate::ffi::PyTuple_GET_ITEM(kwnames, i as Py_ssize_t);
                 if core::ptr::eq(arg, typeref::DEFAULT) {
-                    if unlikely!(num_args & 2 == 2) {
+                    if num_args & 2 == 2 {
+                        cold_path!();
                         return raise_dumps_exception_fixed(
                             "dumps() got multiple values for argument: 'default'",
                         );
                     }
                     default = Some(NonNull::new_unchecked(*args.offset(num_args + i)));
                 } else if core::ptr::eq(arg, typeref::OPTION) {
-                    if unlikely!(num_args & 3 == 3) {
+                    if num_args & 3 == 3 {
+                        cold_path!();
                         return raise_dumps_exception_fixed(
                             "dumps() got multiple values for argument: 'option'",
                         );
@@ -424,16 +432,18 @@ pub(crate) unsafe extern "C" fn dumps(
         }
 
         let mut optsbits: i32 = 0;
-        if unlikely!(optsptr.is_some()) {
-            let opts = optsptr.unwrap();
+        if let Some(opts) = optsptr {
+            cold_path!();
             if core::ptr::eq((*opts.as_ptr()).ob_type, typeref::INT_TYPE) {
                 #[allow(clippy::cast_possible_truncation)]
                 let tmp = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32; // stmt_expr_attributes
                 optsbits = tmp;
-                if unlikely!(!(0..=opt::MAX_OPT).contains(&optsbits)) {
+                if !(0..=opt::MAX_OPT).contains(&optsbits) {
+                    cold_path!();
                     return raise_dumps_exception_fixed("Invalid opts");
                 }
-            } else if unlikely!(!core::ptr::eq(opts.as_ptr(), typeref::NONE)) {
+            } else if !core::ptr::eq(opts.as_ptr(), typeref::NONE) {
+                cold_path!();
                 return raise_dumps_exception_fixed("Invalid opts");
             }
         }
