@@ -27,7 +27,7 @@ pub(crate) use fragment::FragmentSerializer;
 pub(crate) use int::IntSerializer;
 pub(crate) use list::{ListTupleSerializer, ZeroListSerializer};
 pub(crate) use none::NoneSerializer;
-pub(crate) use numpy::{is_numpy_array, is_numpy_scalar, NumpyScalar, NumpySerializer};
+pub(crate) use numpy::{NumpyScalar, NumpySerializer, is_numpy_array, is_numpy_scalar};
 pub(crate) use pybool::BoolSerializer;
 pub(crate) use pyenum::EnumSerializer;
 pub(crate) use unicode::{StrSerializer, StrSubclassSerializer};
