@@ -1,5 +1,6 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
+use crate::ffi::{Py_intptr_t, Py_ssize_t, PyObject, PyTypeObject};
 use crate::opt::Opt;
 use crate::serialize::buffer::SmallFixedBuffer;
 use crate::serialize::error::SerializeError;
@@ -8,12 +9,11 @@ use crate::serialize::per_type::{
 };
 use crate::serialize::serializer::PyObjectSerializer;
 use crate::str::PyStr;
-use crate::typeref::{load_numpy_types, ARRAY_STRUCT_STR, DESCR_STR, DTYPE_STR, NUMPY_TYPES};
+use crate::typeref::{ARRAY_STRUCT_STR, DESCR_STR, DTYPE_STR, NUMPY_TYPES, load_numpy_types};
 use crate::util::isize_to_usize;
 use core::ffi::{c_char, c_int, c_void};
-use jiff::civil::DateTime;
 use jiff::Timestamp;
-use pyo3_ffi::{PyObject, PyTypeObject, Py_intptr_t, Py_ssize_t};
+use jiff::civil::DateTime;
 use serde::ser::{self, Serialize, SerializeSeq, Serializer};
 use std::fmt;
 
@@ -323,9 +323,11 @@ impl Serialize for NumpyArray {
     where
         S: Serializer,
     {
-        if unlikely!(!(self.depth >= self.dimensions() || self.shape()[self.depth] != 0)) {
+        if !(self.depth >= self.dimensions() || self.shape()[self.depth] != 0) {
+            cold_path!();
             ZeroListSerializer::new().serialize(serializer)
         } else if !self.children.is_empty() {
+            cold_path!();
             let mut seq = serializer.serialize_seq(None).unwrap();
             for child in &self.children {
                 seq.serialize_element(child).unwrap();
@@ -886,7 +888,7 @@ impl Serialize for DataTypeBool {
 }
 
 pub(crate) struct NumpyScalar {
-    ptr: *mut pyo3_ffi::PyObject,
+    ptr: *mut PyObject,
     opts: Opt,
 }
 
