@@ -16,22 +16,25 @@ macro_rules! impl_format_scalar {
     };
 }
 
+#[inline(never)]
 #[cfg(all(not(target_arch = "x86_64"), not(feature = "generic_simd")))]
-pub unsafe fn format_escaped_str_scalar(
+pub(crate) unsafe fn format_escaped_str_scalar(
     odst: *mut u8,
     value_ptr: *const u8,
     value_len: usize,
 ) -> usize {
-    let mut dst = odst;
-    let mut src = value_ptr;
+    unsafe {
+        let mut dst = odst;
+        let mut src = value_ptr;
 
-    core::ptr::write(dst, b'"');
-    dst = dst.add(1);
+        core::ptr::write(dst, b'"');
+        dst = dst.add(1);
 
-    impl_format_scalar!(dst, src, value_len);
+        impl_format_scalar!(dst, src, value_len);
 
-    core::ptr::write(dst, b'"');
-    dst = dst.add(1);
+        core::ptr::write(dst, b'"');
+        dst = dst.add(1);
 
-    dst as usize - odst as usize
+        dst as usize - odst as usize
+    }
 }
